/* ***** BEGIN LICENSE BLOCK ***** 
 * Version: RCSL 1.0/RPSL 1.0 
 *  
 * Portions Copyright (c) 1995-2002 RealNetworks, Inc. All Rights Reserved. 
 *      
 * The contents of this file, and the files included with this file, are 
 * subject to the current version of the RealNetworks Public Source License 
 * Version 1.0 (the "RPSL") available at 
 * http://www.helixcommunity.org/content/rpsl unless you have licensed 
 * the file under the RealNetworks Community Source License Version 1.0 
 * (the "RCSL") available at http://www.helixcommunity.org/content/rcsl, 
 * in which case the RCSL will apply. You may also obtain the license terms 
 * directly from RealNetworks.  You may not use this file except in 
 * compliance with the RPSL or, if you have a valid RCSL with RealNetworks 
 * applicable to this file, the RCSL.  Please see the applicable RPSL or 
 * RCSL for the rights, obligations and limitations governing use of the 
 * contents of the file.  
 *  
 * This file is part of the Helix DNA Technology. RealNetworks is the 
 * developer of the Original Code and owns the copyrights in the portions 
 * it created. 
 *  
 * This file, and the files included with this file, is distributed and made 
 * available on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER 
 * EXPRESS OR IMPLIED, AND REALNETWORKS HEREBY DISCLAIMS ALL SUCH WARRANTIES, 
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS 
 * FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT. 
 * 
 * Technology Compatibility Kit Test Suite(s) Location: 
 *    http://www.helixcommunity.org/content/tck 
 * 
 * Contributor(s): 
 *  
 * ***** END LICENSE BLOCK ***** */ 

/**************************************************************************************
 * Fixed-point MP3 decoder
 * Jon Recker (jrecker@real.com), Ken Cooke (kenc@real.com)
 * June 2003
 *
 * 06.01.2014 - Recalculated Huff-Tables for Big-Value codes / M.Schmidt
 *              1874 vs. 4242 words for Huffman table (but slower)
 *
 * hufftabs.c - compressed Huffman code tables
 **************************************************************************************/

#include "coder.h"

/*
 * Tabelle wird mit Variabler Bit-Breite indiziert bis ein
 * dekodierter Wert gefunden wurde. Wird mit der gegebenen
 * Bit-Breite noch kein dekodierter Wert gefunden, so wird
 * ein Offset zum Springen innerhalb der Tabelle gelesen.
 * Der Offset ist speziell Codiert und nutzt aus, dass
 * alle Tabellen mindestens 1-Bit Breite haben.
 *
 * Es gibt folgende zwei Arten von Eintrgen in der Tabelle.
 *
 * ## Normaler Huffman-Code (Blatt-/Leaf-Eintrag) ##
 * Code-Aufbau: 0x0LXY
 * L=Lnge des Codes (1 bis 7)
 * X=X-Wert
 * Y=Y-Wert
 *
 * ## Sprung in Unter-Tabelle (Knoten-/Node-Eintrag) ##
 * Code-Aufbau: 0x0SPP
 * S=Oberstes Bit ist 1, restlichen 3 Bits sind die Gre der Sub-Tabelle-1 (also 0=1Bit-Tabelle)
 * PP=Halber Offset von der nchsten geraden Code-Position aus gesehen (siehe Code...)
 */

/* store Huffman codes as one big table plus table of offsets, since some platforms
 *   don't properly support table-of-tables (table of pointers to other const tables)
 */

// 1874x16Bit Wrter
// Lookup in maximal 4 Schritten
const unsigned short huffTable[] = {
  /* ## Huffman Code-Tabelle 1 ## */
  // LEVEL1 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code  und 1 Sub-Tabellen
  0x0802, 0x0210, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00 und 0 Sub-Tabellen
  0x0111, 0x0101,


  /* ## Huffman Code-Tabelle 2 ## */
  // LEVEL1 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code  und 1 Sub-Tabellen
  0x0901, 0x0100,
  // LEVEL2 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code 0 und 1 Sub-Tabellen
  0x0902, 0x0211, 0x0201, 0x0210,
  // LEVEL3 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code 000 und 1 Sub-Tabellen
  0x0802, 0x0212, 0x0221, 0x0220,
  // LEVEL4 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00000 und 0 Sub-Tabellen
  0x0122, 0x0102,


  /* ## Huffman Code-Tabelle 3 ## */
  // LEVEL1 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code  und 1 Sub-Tabellen
  0x0802, 0x0211, 0x0201, 0x0200,
  // LEVEL2 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00 und 1 Sub-Tabellen
  0x0901, 0x0110,
  // LEVEL3 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code 000 und 1 Sub-Tabellen
  0x0802, 0x0212, 0x0221, 0x0220,
  // LEVEL4 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 00000 und 0 Sub-Tabellen
  0x0122, 0x0102,


  /* ## Huffman Code-Tabelle 5 ## */
  // LEVEL1 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code  und 1 Sub-Tabellen
  0x0901, 0x0100,
  // LEVEL2 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code 0 und 1 Sub-Tabellen
  0x0A02, 0x0211, 0x0201, 0x0210,
  // LEVEL3 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code 000 und 3 Sub-Tabellen
  0x0904, 0x0331, 0x0805, 0x0806, 0x0312, 0x0321, 0x0302, 0x0320,
  // LEVEL4 Tabellen - Lnge 8
  // Sub-Tabelle gre 2 mit vorherigen Code 000000 und 0 Sub-Tabellen
  0x0233, 0x0223, 0x0132, 0x0132,
  // Sub-Tabelle gre 1 mit vorherigen Code 000010 und 0 Sub-Tabellen
  0x0113, 0x0103,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011 und 0 Sub-Tabellen
  0x0130, 0x0122,


  /* ## Huffman Code-Tabelle 6 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 3 Sub-Tabellen
  0x0A04, 0x0908, 0x0809, 0x0301, 0x0211, 0x0211, 0x0310, 0x0300,
  // LEVEL2 Tabellen - Lnge 14
  // Sub-Tabelle gre 3 mit vorherigen Code 000 und 1 Sub-Tabellen
  0x0807, 0x0323, 0x0332, 0x0330, 0x0213, 0x0213, 0x0231, 0x0231,
  // Sub-Tabelle gre 2 mit vorherigen Code 001 und 0 Sub-Tabellen
  0x0222, 0x0202, 0x0112, 0x0112,
  // Sub-Tabelle gre 1 mit vorherigen Code 010 und 0 Sub-Tabellen
  0x0121, 0x0120,
  // LEVEL3 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 000000 und 0 Sub-Tabellen
  0x0133, 0x0103,


  /* ## Huffman Code-Tabelle 7 ## */
  // LEVEL1 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code  und 2 Sub-Tabellen
  0x0A02, 0x0806, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 10
  // Sub-Tabelle gre 3 mit vorherigen Code 00 und 5 Sub-Tabellen
  0x0B05, 0x090D, 0x0A0E, 0x0912, 0x0321, 0x0813, 0x0211, 0x0211,
  // Sub-Tabelle gre 1 mit vorherigen Code 01 und 0 Sub-Tabellen
  0x0101, 0x0110,
  // LEVEL3 Tabellen - Lnge 34
  // Sub-Tabelle gre 4 mit vorherigen Code 00000 und 2 Sub-Tabellen
  0x0811, 0x0812, 0x0435, 0x0444, 0x0425, 0x0452, 0x0315, 0x0315,
  0x0351, 0x0351, 0x0405, 0x0434, 0x0350, 0x0350, 0x0443, 0x0433,
  // Sub-Tabelle gre 2 mit vorherigen Code 00001 und 1 Sub-Tabellen
  0x080B, 0x0214, 0x0241, 0x0240,
  // Sub-Tabelle gre 3 mit vorherigen Code 00010 und 0 Sub-Tabellen
  0x0304, 0x0323, 0x0332, 0x0303, 0x0213, 0x0213, 0x0231, 0x0231,
  // Sub-Tabelle gre 2 mit vorherigen Code 00011 und 0 Sub-Tabellen
  0x0230, 0x0222, 0x0112, 0x0112,
  // Sub-Tabelle gre 1 mit vorherigen Code 00101 und 0 Sub-Tabellen
  0x0102, 0x0120,
  // LEVEL4 Tabellen - Lnge 6
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000 und 0 Sub-Tabellen
  0x0155, 0x0145,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000001 und 0 Sub-Tabellen
  0x0154, 0x0153,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100 und 0 Sub-Tabellen
  0x0124, 0x0142,


  /* ## Huffman Code-Tabelle 8 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 2 Sub-Tabellen
  0x0A04, 0x0808, 0x0211, 0x0211, 0x0301, 0x0310, 0x0200, 0x0200,
  // LEVEL2 Tabellen - Lnge 10
  // Sub-Tabelle gre 3 mit vorherigen Code 000 und 5 Sub-Tabellen
  0x0A05, 0x0A09, 0x090C, 0x090E, 0x090F, 0x0322, 0x0302, 0x0320,
  // Sub-Tabelle gre 1 mit vorherigen Code 001 und 0 Sub-Tabellen
  0x0112, 0x0121,
  // LEVEL3 Tabellen - Lnge 28
  // Sub-Tabelle gre 3 mit vorherigen Code 000000 und 2 Sub-Tabellen
  0x090E, 0x0353, 0x080F, 0x0325, 0x0352, 0x0305, 0x0215, 0x0215,
  // Sub-Tabelle gre 3 mit vorherigen Code 000001 und 0 Sub-Tabellen
  0x0251, 0x0251, 0x0334, 0x0343, 0x0350, 0x0333, 0x0224, 0x0224,
  // Sub-Tabelle gre 2 mit vorherigen Code 000010 und 0 Sub-Tabellen
  0x0242, 0x0214, 0x0141, 0x0141,
  // Sub-Tabelle gre 2 mit vorherigen Code 000011 und 0 Sub-Tabellen
  0x0204, 0x0240, 0x0223, 0x0232,
  // Sub-Tabelle gre 2 mit vorherigen Code 000100 und 0 Sub-Tabellen
  0x0213, 0x0231, 0x0203, 0x0230,
  // LEVEL4 Tabellen - Lnge 6
  // Sub-Tabelle gre 2 mit vorherigen Code 000000000 und 0 Sub-Tabellen
  0x0255, 0x0254, 0x0145, 0x0145,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000010 und 0 Sub-Tabellen
  0x0135, 0x0144,


  /* ## Huffman Code-Tabelle 9 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 4 Sub-Tabellen
  0x0904, 0x0A06, 0x0909, 0x080B, 0x0311, 0x0301, 0x0310, 0x0300,
  // LEVEL2 Tabellen - Lnge 18
  // Sub-Tabelle gre 2 mit vorherigen Code 000 und 4 Sub-Tabellen
  0x0A09, 0x090D, 0x090E, 0x0810,
  // Sub-Tabelle gre 3 mit vorherigen Code 001 und 0 Sub-Tabellen
  0x0323, 0x0332, 0x0213, 0x0213, 0x0231, 0x0231, 0x0303, 0x0330,
  // Sub-Tabelle gre 2 mit vorherigen Code 010 und 0 Sub-Tabellen
  0x0222, 0x0202, 0x0112, 0x0112,
  // Sub-Tabelle gre 1 mit vorherigen Code 011 und 0 Sub-Tabellen
  0x0121, 0x0120,
  // LEVEL3 Tabellen - Lnge 18
  // Sub-Tabelle gre 3 mit vorherigen Code 00000 und 2 Sub-Tabellen
  0x0809, 0x0335, 0x0353, 0x0809, 0x0344, 0x0325, 0x0352, 0x0315,
  // Sub-Tabelle gre 2 mit vorherigen Code 00001 und 1 Sub-Tabellen
  0x0251, 0x0234, 0x0243, 0x0806,
  // Sub-Tabelle gre 2 mit vorherigen Code 00010 und 0 Sub-Tabellen
  0x0224, 0x0242, 0x0233, 0x0240,
  // Sub-Tabelle gre 1 mit vorherigen Code 00011 und 0 Sub-Tabellen
  0x0114, 0x0141,
  // LEVEL4 Tabellen - Lnge 6
  // Sub-Tabelle gre 1 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0155, 0x0145,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011 und 0 Sub-Tabellen
  0x0154, 0x0105,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000111 und 0 Sub-Tabellen
  0x0150, 0x0104,


  /* ## Huffman Code-Tabelle 10 ## */
  // LEVEL1 Tabellen - Lnge 4
  // Sub-Tabelle gre 2 mit vorherigen Code  und 2 Sub-Tabellen
  0x0902, 0x0804, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 6
  // Sub-Tabelle gre 2 mit vorherigen Code 00 und 3 Sub-Tabellen
  0x0C03, 0x0A13, 0x0916, 0x0211,
  // Sub-Tabelle gre 1 mit vorherigen Code 01 und 0 Sub-Tabellen
  0x0101, 0x0110,
  // LEVEL3 Tabellen - Lnge 44
  // Sub-Tabelle gre 5 mit vorherigen Code 0000 und 11 Sub-Tabellen
  0x0916, 0x0918, 0x0819, 0x081A, 0x081A, 0x091B, 0x0527, 0x0572,
  0x081B, 0x0570, 0x0562, 0x081B, 0x0506, 0x081B, 0x0417, 0x0417,
  0x0471, 0x0471, 0x0536, 0x0526, 0x0818, 0x0515, 0x0551, 0x0818,
  0x0416, 0x0416, 0x0461, 0x0461, 0x0460, 0x0460, 0x0505, 0x0550,
  // Sub-Tabelle gre 3 mit vorherigen Code 0001 und 4 Sub-Tabellen
  0x0914, 0x0816, 0x0816, 0x0817, 0x0313, 0x0331, 0x0330, 0x0322,
  // Sub-Tabelle gre 2 mit vorherigen Code 0010 und 0 Sub-Tabellen
  0x0212, 0x0221, 0x0202, 0x0220,
  // LEVEL4 Tabellen - Lnge 38
  // Sub-Tabelle gre 2 mit vorherigen Code 000000000 und 0 Sub-Tabellen
  0x0277, 0x0267, 0x0276, 0x0257,
  // Sub-Tabelle gre 2 mit vorherigen Code 000000001 und 0 Sub-Tabellen
  0x0275, 0x0266, 0x0147, 0x0147,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000010 und 0 Sub-Tabellen
  0x0174, 0x0156,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000011 und 0 Sub-Tabellen
  0x0165, 0x0137,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000100 und 0 Sub-Tabellen
  0x0173, 0x0146,
  // Sub-Tabelle gre 2 mit vorherigen Code 000000101 und 0 Sub-Tabellen
  0x0255, 0x0254, 0x0163, 0x0163,
  // Sub-Tabelle gre 1 mit vorherigen Code 000001000 und 0 Sub-Tabellen
  0x0164, 0x0107,
  // Sub-Tabelle gre 1 mit vorherigen Code 000001011 und 0 Sub-Tabellen
  0x0145, 0x0135,
  // Sub-Tabelle gre 1 mit vorherigen Code 000001101 und 0 Sub-Tabellen
  0x0153, 0x0144,
  // Sub-Tabelle gre 1 mit vorherigen Code 000010100 und 0 Sub-Tabellen
  0x0125, 0x0152,
  // Sub-Tabelle gre 1 mit vorherigen Code 000010111 und 0 Sub-Tabellen
  0x0134, 0x0143,
  // Sub-Tabelle gre 2 mit vorherigen Code 0001000 und 0 Sub-Tabellen
  0x0224, 0x0242, 0x0233, 0x0204,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001001 und 0 Sub-Tabellen
  0x0114, 0x0141,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010 und 0 Sub-Tabellen
  0x0140, 0x0123,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001011 und 0 Sub-Tabellen
  0x0132, 0x0103,


  /* ## Huffman Code-Tabelle 11 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 3 Sub-Tabellen
  0x0C04, 0x0A14, 0x0917, 0x0311, 0x0301, 0x0310, 0x0200, 0x0200,
  // LEVEL2 Tabellen - Lnge 44
  // Sub-Tabelle gre 5 mit vorherigen Code 000 und 9 Sub-Tabellen
  0x0916, 0x0918, 0x0919, 0x081B, 0x091B, 0x0527, 0x0572, 0x081C,
  0x0471, 0x0471, 0x0517, 0x0570, 0x0536, 0x0563, 0x0560, 0x0819,
  0x0819, 0x0515, 0x0462, 0x0462, 0x0526, 0x0506, 0x0416, 0x0416,
  0x0461, 0x0461, 0x0551, 0x0534, 0x0550, 0x0814, 0x0524, 0x0542,
  // Sub-Tabelle gre 3 mit vorherigen Code 001 und 3 Sub-Tabellen
  0x0913, 0x0815, 0x0313, 0x0331, 0x0814, 0x0322, 0x0221, 0x0221,
  // Sub-Tabelle gre 2 mit vorherigen Code 010 und 0 Sub-Tabellen
  0x0112, 0x0112, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 34
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0277, 0x0267, 0x0276, 0x0275,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000001 und 1 Sub-Tabellen
  0x0266, 0x0247, 0x0274, 0x080E,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x0256, 0x0265, 0x0137, 0x0137,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011 und 0 Sub-Tabellen
  0x0173, 0x0146,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000100 und 0 Sub-Tabellen
  0x0245, 0x0254, 0x0235, 0x0253,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000111 und 0 Sub-Tabellen
  0x0164, 0x0107,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001111 und 0 Sub-Tabellen
  0x0144, 0x0125,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000 und 0 Sub-Tabellen
  0x0152, 0x0105,
  // Sub-Tabelle gre 1 mit vorherigen Code 00011101 und 0 Sub-Tabellen
  0x0143, 0x0133,
  // Sub-Tabelle gre 2 mit vorherigen Code 001000 und 0 Sub-Tabellen
  0x0214, 0x0241, 0x0204, 0x0240,
  // Sub-Tabelle gre 1 mit vorherigen Code 001001 und 0 Sub-Tabellen
  0x0123, 0x0132,
  // Sub-Tabelle gre 1 mit vorherigen Code 001100 und 0 Sub-Tabellen
  0x0103, 0x0130,
  // LEVEL4 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000111 und 0 Sub-Tabellen
  0x0157, 0x0155,


  /* ## Huffman Code-Tabelle 12 ## */
  // LEVEL1 Tabellen - Lnge 8
  // Sub-Tabelle gre 3 mit vorherigen Code  und 5 Sub-Tabellen
  0x0C04, 0x0814, 0x0914, 0x0816, 0x0916, 0x0311, 0x0301, 0x0310,
  // LEVEL2 Tabellen - Lnge 44
  // Sub-Tabelle gre 5 mit vorherigen Code 000 und 7 Sub-Tabellen
  0x0916, 0x0818, 0x0818, 0x0819, 0x0556, 0x0537, 0x0818, 0x0527,
  0x0572, 0x0546, 0x0564, 0x0517, 0x0571, 0x0816, 0x0536, 0x0563,
  0x0545, 0x0554, 0x0544, 0x0814, 0x0426, 0x0426, 0x0462, 0x0462,
  0x0461, 0x0461, 0x0516, 0x0560, 0x0535, 0x0553, 0x0525, 0x0552,
  // Sub-Tabelle gre 1 mit vorherigen Code 001 und 2 Sub-Tabellen
  0x0A0E, 0x0912,
  // Sub-Tabelle gre 2 mit vorherigen Code 010 und 1 Sub-Tabellen
  0x0913, 0x0213, 0x0231, 0x0222,
  // Sub-Tabelle gre 1 mit vorherigen Code 011 und 0 Sub-Tabellen
  0x0112, 0x0121,
  // Sub-Tabelle gre 2 mit vorherigen Code 100 und 0 Sub-Tabellen
  0x0202, 0x0220, 0x0100, 0x0100,
  // LEVEL3 Tabellen - Lnge 32
  // Sub-Tabelle gre 2 mit vorherigen Code 00000000 und 0 Sub-Tabellen
  0x0277, 0x0267, 0x0176, 0x0176,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000001 und 0 Sub-Tabellen
  0x0157, 0x0175,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010 und 0 Sub-Tabellen
  0x0166, 0x0147,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011 und 0 Sub-Tabellen
  0x0174, 0x0165,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110 und 0 Sub-Tabellen
  0x0173, 0x0155,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001101 und 0 Sub-Tabellen
  0x0107, 0x0170,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010011 und 0 Sub-Tabellen
  0x0106, 0x0105,
  // Sub-Tabelle gre 3 mit vorherigen Code 0010 und 1 Sub-Tabellen
  0x0315, 0x0351, 0x0334, 0x0343, 0x0806, 0x0324, 0x0342, 0x0314,
  // Sub-Tabelle gre 2 mit vorherigen Code 0011 und 0 Sub-Tabellen
  0x0233, 0x0241, 0x0223, 0x0232,
  // Sub-Tabelle gre 2 mit vorherigen Code 01000 und 0 Sub-Tabellen
  0x0240, 0x0203, 0x0130, 0x0130,
  // LEVEL4 Tabellen - Lnge 2
  // Sub-Tabelle gre 1 mit vorherigen Code 0010100 und 0 Sub-Tabellen
  0x0150, 0x0104,


  /* ## Huffman Code-Tabelle 13 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 4 Sub-Tabellen
  0x0D08, 0x0C28, 0x0A37, 0x093B, 0x0411, 0x0401, 0x0310, 0x0310,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 108
  // Sub-Tabelle gre 6 mit vorherigen Code 0000 und 36 Sub-Tabellen
  0x0C36, 0x0B46, 0x0A4D, 0x0A51, 0x0A54, 0x0958, 0x0A59, 0x0A5D,
  0x0960, 0x0A62, 0x0965, 0x0967, 0x0968, 0x086A, 0x086A, 0x096B,
  0x096C, 0x096E, 0x096F, 0x0971, 0x0972, 0x0974, 0x0975, 0x06B2,
  0x061B, 0x06B1, 0x0875, 0x0876, 0x0876, 0x0877, 0x062A, 0x06A2,
  0x061A, 0x06A1, 0x0875, 0x06A0, 0x0875, 0x0693, 0x0875, 0x0876,
  0x0629, 0x0692, 0x0875, 0x0638, 0x0683, 0x0875, 0x0875, 0x0876,
  0x0519, 0x0519, 0x0591, 0x0591, 0x0609, 0x0690, 0x0648, 0x0684,
  0x0672, 0x0872, 0x0528, 0x0528, 0x0582, 0x0582, 0x0518, 0x0518,
  // Sub-Tabelle gre 5 mit vorherigen Code 0001 und 7 Sub-Tabellen
  0x086F, 0x0517, 0x0571, 0x086F, 0x086F, 0x0870, 0x0870, 0x0871,
  0x0481, 0x0481, 0x0508, 0x0580, 0x0516, 0x0561, 0x0506, 0x0560,
  0x086D, 0x0525, 0x0552, 0x0505, 0x0415, 0x0415, 0x0451, 0x0451,
  0x0534, 0x0543, 0x0550, 0x0524, 0x0542, 0x0533, 0x0414, 0x0414,
  // Sub-Tabelle gre 3 mit vorherigen Code 0010 und 2 Sub-Tabellen
  0x0341, 0x0866, 0x0866, 0x0313, 0x0331, 0x0303, 0x0330, 0x0322,
  // Sub-Tabelle gre 2 mit vorherigen Code 0011 und 0 Sub-Tabellen
  0x0212, 0x0221, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 196
  // Sub-Tabelle gre 5 mit vorherigen Code 0000000000 und 9 Sub-Tabellen
  0x0B62, 0x086A, 0x086A, 0x086B, 0x086B, 0x096C, 0x05EC, 0x05DD,
  0x086C, 0x05BE, 0x05EB, 0x059F, 0x05F9, 0x05EA, 0x05BD, 0x05DB,
  0x058F, 0x05F8, 0x05CC, 0x0868, 0x058E, 0x0868, 0x04F7, 0x04F7,
  0x04DA, 0x04DA, 0x05AD, 0x05BC, 0x05CB, 0x05F6, 0x046F, 0x046F,
  // Sub-Tabelle gre 4 mit vorherigen Code 0000000001 und 1 Sub-Tabellen
  0x04E8, 0x045F, 0x049D, 0x04D9, 0x04F5, 0x04E7, 0x04AC, 0x04BB,
  0x044F, 0x04F4, 0x085E, 0x04F3, 0x033F, 0x033F, 0x048D, 0x04D8,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000010 und 3 Sub-Tabellen
  0x032F, 0x03F2, 0x085B, 0x030F, 0x085B, 0x03AB, 0x085B, 0x034E,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000011 und 2 Sub-Tabellen
  0x085B, 0x033E, 0x03B9, 0x085B, 0x021F, 0x021F, 0x02F1, 0x02F1,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000100 und 0 Sub-Tabellen
  0x02F0, 0x02F0, 0x03BA, 0x03E5, 0x03E4, 0x038C, 0x036D, 0x03E3,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000000101 und 1 Sub-Tabellen
  0x02E2, 0x0855, 0x021E, 0x02E1,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000110 und 0 Sub-Tabellen
  0x03E0, 0x035D, 0x03D5, 0x037C, 0x03C7, 0x034D, 0x038B, 0x03B8,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000000111 und 0 Sub-Tabellen
  0x03D4, 0x039A, 0x03A9, 0x036C, 0x02C6, 0x02C6, 0x023D, 0x023D,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001000 und 1 Sub-Tabellen
  0x084C, 0x022D, 0x02D2, 0x021D,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000001001 und 0 Sub-Tabellen
  0x02B7, 0x02B7, 0x035C, 0x03C5, 0x0399, 0x037A, 0x02C3, 0x02C3,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001010 und 1 Sub-Tabellen
  0x0847, 0x024B, 0x01D1, 0x01D1,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001011 und 0 Sub-Tabellen
  0x020D, 0x02D0, 0x028A, 0x02A8,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001100 und 0 Sub-Tabellen
  0x024C, 0x02C4, 0x026B, 0x02B6,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000001101 und 0 Sub-Tabellen
  0x013C, 0x012C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000001110 und 0 Sub-Tabellen
  0x01C2, 0x015B,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000001111 und 0 Sub-Tabellen
  0x02B5, 0x0289, 0x011C, 0x011C,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010000 und 0 Sub-Tabellen
  0x01C1, 0x01C1, 0x0298, 0x020C,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010001 und 0 Sub-Tabellen
  0x01C0, 0x01C0, 0x02B4, 0x026A,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010010 und 0 Sub-Tabellen
  0x02A6, 0x0279, 0x013B, 0x013B,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010011 und 0 Sub-Tabellen
  0x01B3, 0x01B3, 0x0288, 0x025A,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010100 und 0 Sub-Tabellen
  0x012B, 0x012B, 0x02A5, 0x0269,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010101 und 0 Sub-Tabellen
  0x01A4, 0x01A4, 0x0278, 0x0287,
  // Sub-Tabelle gre 2 mit vorherigen Code 0000010110 und 0 Sub-Tabellen
  0x0194, 0x0194, 0x0277, 0x0276,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000011010 und 0 Sub-Tabellen
  0x010B, 0x01B0,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000011011 und 0 Sub-Tabellen
  0x0196, 0x014A,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000011100 und 0 Sub-Tabellen
  0x013A, 0x01A3,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000011101 und 0 Sub-Tabellen
  0x0159, 0x0195,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100010 und 0 Sub-Tabellen
  0x010A, 0x0168,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100100 und 0 Sub-Tabellen
  0x0186, 0x0149,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100110 und 0 Sub-Tabellen
  0x0139, 0x0158,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000100111 und 0 Sub-Tabellen
  0x0185, 0x0167,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101010 und 0 Sub-Tabellen
  0x0157, 0x0175,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101101 und 0 Sub-Tabellen
  0x0166, 0x0147,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101110 und 0 Sub-Tabellen
  0x0174, 0x0156,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101111 und 0 Sub-Tabellen
  0x0165, 0x0173,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000111001 und 0 Sub-Tabellen
  0x0146, 0x0164,
  // Sub-Tabelle gre 1 mit vorherigen Code 000100000 und 0 Sub-Tabellen
  0x0137, 0x0127,
  // Sub-Tabelle gre 1 mit vorherigen Code 000100011 und 0 Sub-Tabellen
  0x0155, 0x0107,
  // Sub-Tabelle gre 1 mit vorherigen Code 000100100 und 0 Sub-Tabellen
  0x0170, 0x0136,
  // Sub-Tabelle gre 1 mit vorherigen Code 000100101 und 0 Sub-Tabellen
  0x0163, 0x0145,
  // Sub-Tabelle gre 1 mit vorherigen Code 000100110 und 0 Sub-Tabellen
  0x0154, 0x0126,
  // Sub-Tabelle gre 1 mit vorherigen Code 000100111 und 0 Sub-Tabellen
  0x0162, 0x0135,
  // Sub-Tabelle gre 1 mit vorherigen Code 000110000 und 0 Sub-Tabellen
  0x0153, 0x0144,
  // Sub-Tabelle gre 1 mit vorherigen Code 0010001 und 0 Sub-Tabellen
  0x0104, 0x0140,
  // Sub-Tabelle gre 1 mit vorherigen Code 0010010 und 0 Sub-Tabellen
  0x0123, 0x0132,
  // LEVEL4 Tabellen - Lnge 52
  // Sub-Tabelle gre 4 mit vorherigen Code 000000000000000 und 0 Sub-Tabellen
  0x04FE, 0x04FC, 0x03FD, 0x03FD, 0x02ED, 0x02ED, 0x02ED, 0x02ED,
  0x01FF, 0x01FF, 0x01FF, 0x01FF, 0x01FF, 0x01FF, 0x01FF, 0x01FF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000000001 und 0 Sub-Tabellen
  0x01EF, 0x01DF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000000010 und 0 Sub-Tabellen
  0x01EE, 0x01CF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000000011 und 0 Sub-Tabellen
  0x01DE, 0x01BF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000000100 und 0 Sub-Tabellen
  0x01FB, 0x01CE,
  // Sub-Tabelle gre 2 mit vorherigen Code 000000000000101 und 0 Sub-Tabellen
  0x01DC, 0x01DC, 0x02AF, 0x02E9,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000001000 und 0 Sub-Tabellen
  0x01FA, 0x01CD,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000010011 und 0 Sub-Tabellen
  0x01AE, 0x019E,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000010101 und 0 Sub-Tabellen
  0x017F, 0x017E,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000000011010 und 0 Sub-Tabellen
  0x01CA, 0x01E6,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000010010 und 0 Sub-Tabellen
  0x016E, 0x019C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000010100 und 0 Sub-Tabellen
  0x01C9, 0x015E,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000010110 und 0 Sub-Tabellen
  0x017D, 0x01D7,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000011000 und 0 Sub-Tabellen
  0x01C8, 0x01D6,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000000011011 und 0 Sub-Tabellen
  0x019B, 0x01AA,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000010101 und 0 Sub-Tabellen
  0x012E, 0x010E,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000100000 und 0 Sub-Tabellen
  0x01D3, 0x017B,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000101000 und 0 Sub-Tabellen
  0x01A7, 0x0197,


  /* ## Huffman Code-Tabelle 15 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 10 Sub-Tabellen
  0x0A08, 0x080C, 0x0C0C, 0x0B1C, 0x0A23, 0x0A27, 0x092A, 0x092C,
  0x082D, 0x082E, 0x0311, 0x0311, 0x0401, 0x0410, 0x0300, 0x0300,
  // LEVEL2 Tabellen - Lnge 86
  // Sub-Tabelle gre 3 mit vorherigen Code 0000 und 8 Sub-Tabellen
  0x0C2B, 0x0B3B, 0x0B42, 0x0B4A, 0x0B51, 0x0A59, 0x0A5C, 0x0A60,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001 und 2 Sub-Tabellen
  0x0C63, 0x0B73,
  // Sub-Tabelle gre 5 mit vorherigen Code 0010 und 0 Sub-Tabellen
  0x0529, 0x0567, 0x0576, 0x0592, 0x0491, 0x0491, 0x0519, 0x0590,
  0x0548, 0x0584, 0x0557, 0x0575, 0x0538, 0x0583, 0x0566, 0x0547,
  0x0428, 0x0428, 0x0482, 0x0482, 0x0418, 0x0418, 0x0481, 0x0481,
  0x0574, 0x0508, 0x0580, 0x0556, 0x0565, 0x0537, 0x0573, 0x0546,
  // Sub-Tabelle gre 4 mit vorherigen Code 0011 und 2 Sub-Tabellen
  0x0427, 0x0472, 0x0464, 0x0417, 0x0455, 0x0471, 0x0867, 0x0436,
  0x0463, 0x0445, 0x0454, 0x0426, 0x0462, 0x0416, 0x0864, 0x0435,
  // Sub-Tabelle gre 3 mit vorherigen Code 0100 und 2 Sub-Tabellen
  0x0361, 0x0864, 0x0325, 0x0352, 0x0315, 0x0351, 0x0862, 0x0334,
  // Sub-Tabelle gre 3 mit vorherigen Code 0101 und 0 Sub-Tabellen
  0x0343, 0x0324, 0x0342, 0x0333, 0x0241, 0x0241, 0x0314, 0x0304,
  // Sub-Tabelle gre 2 mit vorherigen Code 0110 und 1 Sub-Tabellen
  0x0223, 0x0232, 0x085D, 0x0213,
  // Sub-Tabelle gre 2 mit vorherigen Code 0111 und 0 Sub-Tabellen
  0x0231, 0x0230, 0x0122, 0x0122,
  // Sub-Tabelle gre 1 mit vorherigen Code 1000 und 0 Sub-Tabellen
  0x0112, 0x0121,
  // Sub-Tabelle gre 1 mit vorherigen Code 1001 und 0 Sub-Tabellen
  0x0102, 0x0120,
  // LEVEL3 Tabellen - Lnge 178
  // Sub-Tabelle gre 5 mit vorherigen Code 0000000 und 7 Sub-Tabellen
  0x0859, 0x085A, 0x05EE, 0x085A, 0x085A, 0x085B, 0x05FB, 0x085B,
  0x05DD, 0x05AF, 0x05FA, 0x05BE, 0x05EB, 0x05CD, 0x05DC, 0x059F,
  0x05F9, 0x05EA, 0x05BD, 0x05DB, 0x058F, 0x05F8, 0x05CC, 0x059E,
  0x05E9, 0x057F, 0x05F7, 0x05AD, 0x05DA, 0x05BC, 0x056F, 0x0850,
  // Sub-Tabelle gre 4 mit vorherigen Code 0000001 und 3 Sub-Tabellen
  0x04CB, 0x04F6, 0x084F, 0x0850, 0x04F5, 0x047E, 0x04E7, 0x04AC,
  0x04CA, 0x04BB, 0x084D, 0x044F, 0x04F4, 0x043F, 0x04F3, 0x04D8,
  // Sub-Tabelle gre 4 mit vorherigen Code 0000010 und 1 Sub-Tabellen
  0x04E6, 0x042F, 0x04F2, 0x084A, 0x041F, 0x04F1, 0x049C, 0x04C9,
  0x045E, 0x04AB, 0x04BA, 0x04E5, 0x047D, 0x04D7, 0x044E, 0x04E4,
  // Sub-Tabelle gre 4 mit vorherigen Code 0000011 und 1 Sub-Tabellen
  0x048C, 0x04C8, 0x043E, 0x046D, 0x04D6, 0x04E3, 0x049B, 0x04B9,
  0x042E, 0x04AA, 0x04E2, 0x041E, 0x04E1, 0x083E, 0x045D, 0x04D5,
  // Sub-Tabelle gre 4 mit vorherigen Code 0000100 und 0 Sub-Tabellen
  0x047C, 0x04C7, 0x044D, 0x048B, 0x03D4, 0x03D4, 0x04B8, 0x049A,
  0x04A9, 0x046C, 0x04C6, 0x043D, 0x03D3, 0x03D3, 0x03D2, 0x03D2,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000101 und 2 Sub-Tabellen
  0x0835, 0x031D, 0x037B, 0x03B7, 0x03D1, 0x0834, 0x03C5, 0x038A,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000110 und 1 Sub-Tabellen
  0x03A8, 0x034C, 0x03C4, 0x036B, 0x03B6, 0x0831, 0x033C, 0x03C3,
  // Sub-Tabelle gre 3 mit vorherigen Code 0000111 und 1 Sub-Tabellen
  0x037A, 0x03A7, 0x03A6, 0x082F, 0x02C2, 0x02C2, 0x032C, 0x035B,
  // Sub-Tabelle gre 5 mit vorherigen Code 00010 und 0 Sub-Tabellen
  0x05B5, 0x051C, 0x0589, 0x0598, 0x05C1, 0x054B, 0x05B4, 0x056A,
  0x053B, 0x0579, 0x04B3, 0x04B3, 0x0597, 0x0588, 0x052B, 0x055A,
  0x04B2, 0x04B2, 0x05A5, 0x051B, 0x04B1, 0x04B1, 0x05B0, 0x0569,
  0x0596, 0x054A, 0x05A4, 0x0578, 0x0587, 0x053A, 0x04A3, 0x04A3,
  // Sub-Tabelle gre 4 mit vorherigen Code 00011 und 2 Sub-Tabellen
  0x0459, 0x0495, 0x042A, 0x04A2, 0x041A, 0x04A1, 0x081A, 0x0468,
  0x0486, 0x0449, 0x0494, 0x0439, 0x0493, 0x0818, 0x0458, 0x0485,
  // Sub-Tabelle gre 1 mit vorherigen Code 00110110 und 0 Sub-Tabellen
  0x0107, 0x0170,
  // Sub-Tabelle gre 1 mit vorherigen Code 00111110 und 0 Sub-Tabellen
  0x0106, 0x0160,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100001 und 0 Sub-Tabellen
  0x0153, 0x0144,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100110 und 0 Sub-Tabellen
  0x0105, 0x0150,
  // Sub-Tabelle gre 1 mit vorherigen Code 011010 und 0 Sub-Tabellen
  0x0140, 0x0103,
  // LEVEL4 Tabellen - Lnge 36
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000000 und 0 Sub-Tabellen
  0x01FF, 0x01EF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000001 und 0 Sub-Tabellen
  0x01FE, 0x01DF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000011 und 0 Sub-Tabellen
  0x01FD, 0x01CF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000100 und 0 Sub-Tabellen
  0x01FC, 0x01DE,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000101 und 0 Sub-Tabellen
  0x01ED, 0x01BF,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000000111 und 0 Sub-Tabellen
  0x01CE, 0x01EC,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000011111 und 0 Sub-Tabellen
  0x01AE, 0x010F,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010010 und 0 Sub-Tabellen
  0x018E, 0x01E8,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000010011 und 0 Sub-Tabellen
  0x015F, 0x019D,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000011010 und 0 Sub-Tabellen
  0x01D9, 0x018D,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000100011 und 0 Sub-Tabellen
  0x016E, 0x01F0,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000111101 und 0 Sub-Tabellen
  0x010E, 0x01E0,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101000 und 0 Sub-Tabellen
  0x012D, 0x010D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101101 und 0 Sub-Tabellen
  0x015C, 0x01D0,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000110101 und 0 Sub-Tabellen
  0x0199, 0x010C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000111011 und 0 Sub-Tabellen
  0x01C0, 0x010B,
  // Sub-Tabelle gre 1 mit vorherigen Code 000110110 und 0 Sub-Tabellen
  0x010A, 0x01A0,
  // Sub-Tabelle gre 1 mit vorherigen Code 000111101 und 0 Sub-Tabellen
  0x0177, 0x0109,


  /* ## Huffman Code-Tabelle 16 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 4 Sub-Tabellen
  0x0C08, 0x0918, 0x0B19, 0x0921, 0x0411, 0x0401, 0x0310, 0x0310,
  0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100, 0x0100,
  // LEVEL2 Tabellen - Lnge 56
  // Sub-Tabelle gre 5 mit vorherigen Code 0000 und 18 Sub-Tabellen
  0x091C, 0x091E, 0x091F, 0x0921, 0x0822, 0x0823, 0x04FF, 0x04FF,
  0x0822, 0x054F, 0x05F4, 0x05F3, 0x05F0, 0x0C21, 0x04F2, 0x04F2,
  0x052F, 0x050F, 0x041F, 0x041F, 0x04F1, 0x04F1, 0x0C2C, 0x0B3C,
  0x0B43, 0x0A4B, 0x0A4E, 0x0A52, 0x0A55, 0x0959, 0x0A5A, 0x0A5E,
  // Sub-Tabelle gre 2 mit vorherigen Code 0001 und 4 Sub-Tabellen
  0x0C61, 0x0B71, 0x0B78, 0x0A80,
  // Sub-Tabelle gre 4 mit vorherigen Code 0010 und 4 Sub-Tabellen
  0x0883, 0x0884, 0x0884, 0x0414, 0x0441, 0x0884, 0x0423, 0x0432,
  0x0313, 0x0313, 0x0331, 0x0331, 0x0403, 0x0430, 0x0322, 0x0322,
  // Sub-Tabelle gre 2 mit vorherigen Code 0011 und 0 Sub-Tabellen
  0x0212, 0x0221, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 250
  // Sub-Tabelle gre 2 mit vorherigen Code 000000000 und 0 Sub-Tabellen
  0x02EF, 0x02FE, 0x02DF, 0x02FD,
  // Sub-Tabelle gre 2 mit vorherigen Code 000000001 und 0 Sub-Tabellen
  0x02CF, 0x02FC, 0x02BF, 0x02FB,
  // Sub-Tabelle gre 2 mit vorherigen Code 000000010 und 0 Sub-Tabellen
  0x01AF, 0x01AF, 0x02FA, 0x029F,
  // Sub-Tabelle gre 2 mit vorherigen Code 000000011 und 0 Sub-Tabellen
  0x02F9, 0x02F8, 0x018F, 0x018F,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000100 und 0 Sub-Tabellen
  0x017F, 0x01F7,
  // Sub-Tabelle gre 1 mit vorherigen Code 000000101 und 0 Sub-Tabellen
  0x016F, 0x01F6,
  // Sub-Tabelle gre 1 mit vorherigen Code 000001000 und 0 Sub-Tabellen
  0x015F, 0x01F5,
  // Sub-Tabelle gre 5 mit vorherigen Code 000001101 und 7 Sub-Tabellen
  0x013F, 0x013F, 0x013F, 0x013F, 0x013F, 0x013F, 0x013F, 0x013F,
  0x013F, 0x013F, 0x013F, 0x013F, 0x013F, 0x013F, 0x013F, 0x013F,
  0x0A6A, 0x096E, 0x05EE, 0x086F, 0x05BE, 0x05CD, 0x086E, 0x05AE,
  0x05CC, 0x086E, 0x086E, 0x05CA, 0x086E, 0x055E, 0x04BD, 0x04BD,
  // Sub-Tabelle gre 5 mit vorherigen Code 000010110 und 0 Sub-Tabellen
  0x049E, 0x049E, 0x05BC, 0x05CB, 0x058E, 0x05E8, 0x059D, 0x05E7,
  0x05BB, 0x058D, 0x05D8, 0x056E, 0x04E6, 0x04E6, 0x049C, 0x049C,
  0x05AB, 0x05BA, 0x05E5, 0x05D7, 0x044E, 0x044E, 0x05E4, 0x058C,
  0x04C8, 0x04C8, 0x043E, 0x043E, 0x046D, 0x046D, 0x05D6, 0x059B,
  // Sub-Tabelle gre 4 mit vorherigen Code 000010111 und 3 Sub-Tabellen
  0x085D, 0x04E1, 0x04D4, 0x085D, 0x047B, 0x085D, 0x03E3, 0x03E3,
  0x040E, 0x04E0, 0x045D, 0x04D5, 0x047C, 0x04C7, 0x044D, 0x048B,
  // Sub-Tabelle gre 4 mit vorherigen Code 000011000 und 0 Sub-Tabellen
  0x049A, 0x046C, 0x04C6, 0x043D, 0x045C, 0x04C5, 0x030D, 0x030D,
  0x048A, 0x04A8, 0x0499, 0x044C, 0x04B6, 0x047A, 0x033C, 0x033C,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011001 und 2 Sub-Tabellen
  0x0850, 0x031C, 0x03C0, 0x0850, 0x02E2, 0x02E2, 0x032E, 0x031E,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011010 und 1 Sub-Tabellen
  0x03D3, 0x032D, 0x03D2, 0x03D1, 0x033B, 0x084C, 0x021D, 0x021D,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011011 und 0 Sub-Tabellen
  0x03C4, 0x036B, 0x03C3, 0x03A7, 0x022C, 0x022C, 0x03C2, 0x03B5,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011100 und 0 Sub-Tabellen
  0x03C1, 0x030C, 0x034B, 0x03B4, 0x036A, 0x03A6, 0x02B3, 0x02B3,
  // Sub-Tabelle gre 2 mit vorherigen Code 000011101 und 1 Sub-Tabellen
  0x0843, 0x022B, 0x02B2, 0x021B,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011110 und 0 Sub-Tabellen
  0x02B1, 0x02B1, 0x030B, 0x03B0, 0x0369, 0x0396, 0x034A, 0x03A4,
  // Sub-Tabelle gre 3 mit vorherigen Code 000011111 und 0 Sub-Tabellen
  0x0378, 0x0387, 0x02A3, 0x02A3, 0x033A, 0x0359, 0x022A, 0x022A,
  // Sub-Tabelle gre 5 mit vorherigen Code 000100 und 3 Sub-Tabellen
  0x083A, 0x05A1, 0x083A, 0x0594, 0x083A, 0x0567, 0x04A2, 0x04A2,
  0x041A, 0x041A, 0x050A, 0x05A0, 0x0539, 0x0593, 0x0558, 0x0585,
  0x0429, 0x0429, 0x0492, 0x0492, 0x0576, 0x0509, 0x0419, 0x0419,
  0x0491, 0x0491, 0x0590, 0x0548, 0x0584, 0x0575, 0x0538, 0x0583,
  // Sub-Tabelle gre 4 mit vorherigen Code 000101 und 5 Sub-Tabellen
  0x082D, 0x0482, 0x082D, 0x0418, 0x0481, 0x0480, 0x082C, 0x0437,
  0x0473, 0x082C, 0x0427, 0x0472, 0x082B, 0x0407, 0x0317, 0x0317,
  // Sub-Tabelle gre 4 mit vorherigen Code 000110 und 0 Sub-Tabellen
  0x0371, 0x0371, 0x0470, 0x0436, 0x0463, 0x0445, 0x0454, 0x0426,
  0x0362, 0x0362, 0x0316, 0x0316, 0x0361, 0x0361, 0x0406, 0x0460,
  // Sub-Tabelle gre 3 mit vorherigen Code 000111 und 1 Sub-Tabellen
  0x0353, 0x0822, 0x0325, 0x0352, 0x0251, 0x0251, 0x0315, 0x0305,
  // Sub-Tabelle gre 1 mit vorherigen Code 00100000 und 0 Sub-Tabellen
  0x0134, 0x0143,
  // Sub-Tabelle gre 1 mit vorherigen Code 00100001 und 0 Sub-Tabellen
  0x0150, 0x0124,
  // Sub-Tabelle gre 1 mit vorherigen Code 00100010 und 0 Sub-Tabellen
  0x0142, 0x0133,
  // Sub-Tabelle gre 1 mit vorherigen Code 00100101 und 0 Sub-Tabellen
  0x0104, 0x0140,
  // LEVEL4 Tabellen - Lnge 54
  // Sub-Tabelle gre 3 mit vorherigen Code 00000110110000 und 0 Sub-Tabellen
  0x02CE, 0x02CE, 0x03EC, 0x03DD, 0x01DE, 0x01DE, 0x01DE, 0x01DE,
  // Sub-Tabelle gre 2 mit vorherigen Code 00000110110001 und 0 Sub-Tabellen
  0x01E9, 0x01E9, 0x02EA, 0x02D9,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110110011 und 0 Sub-Tabellen
  0x01ED, 0x01EB,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110110110 und 0 Sub-Tabellen
  0x01DC, 0x01DB,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110111001 und 0 Sub-Tabellen
  0x01AD, 0x01DA,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110111010 und 0 Sub-Tabellen
  0x017E, 0x01AC,
  // Sub-Tabelle gre 1 mit vorherigen Code 00000110111100 und 0 Sub-Tabellen
  0x01C9, 0x017D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101110000 und 0 Sub-Tabellen
  0x01B9, 0x01AA,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101110011 und 0 Sub-Tabellen
  0x01B8, 0x01A9,
  // Sub-Tabelle gre 1 mit vorherigen Code 0000101110101 und 0 Sub-Tabellen
  0x01B7, 0x01D0,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011001000 und 0 Sub-Tabellen
  0x015B, 0x0189,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011001011 und 0 Sub-Tabellen
  0x0198, 0x0179,
  // Sub-Tabelle gre 1 mit vorherigen Code 000011010101 und 0 Sub-Tabellen
  0x0197, 0x0188,
  // Sub-Tabelle gre 1 mit vorherigen Code 00001110100 und 0 Sub-Tabellen
  0x015A, 0x01A5,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000000 und 0 Sub-Tabellen
  0x0195, 0x0168,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000010 und 0 Sub-Tabellen
  0x0186, 0x0177,
  // Sub-Tabelle gre 1 mit vorherigen Code 00010000100 und 0 Sub-Tabellen
  0x0149, 0x0157,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010000 und 0 Sub-Tabellen
  0x0166, 0x0128,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010010 und 0 Sub-Tabellen
  0x0147, 0x0174,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001010110 und 0 Sub-Tabellen
  0x0108, 0x0156,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001011001 und 0 Sub-Tabellen
  0x0165, 0x0146,
  // Sub-Tabelle gre 1 mit vorherigen Code 0001011100 und 0 Sub-Tabellen
  0x0164, 0x0155,
  // Sub-Tabelle gre 1 mit vorherigen Code 000111001 und 0 Sub-Tabellen
  0x0135, 0x0144,


  /* ## Huffman Code-Tabelle 24 ## */
  // LEVEL1 Tabellen - Lnge 16
  // Sub-Tabelle gre 4 mit vorherigen Code  und 11 Sub-Tabellen
  0x0B08, 0x0A10, 0x0A13, 0x04FF, 0x0D16, 0x0936, 0x0C37, 0x0B47,
  0x0A4E, 0x0A52, 0x0955, 0x0957, 0x0411, 0x0401, 0x0410, 0x0400,
  // LEVEL2 Tabellen - Lnge 172
  // Sub-Tabelle gre 4 mit vorherigen Code 0000 und 0 Sub-Tabellen
  0x04EF, 0x04FE, 0x04DF, 0x04FD, 0x04CF, 0x04FC, 0x04BF, 0x04FB,
  0x03FA, 0x03FA, 0x04AF, 0x049F, 0x03F9, 0x03F9, 0x03F8, 0x03F8,
  // Sub-Tabelle gre 3 mit vorherigen Code 0001 und 1 Sub-Tabellen
  0x084E, 0x03F7, 0x036F, 0x03F6, 0x035F, 0x03F5, 0x034F, 0x03F4,
  // Sub-Tabelle gre 3 mit vorherigen Code 0010 und 3 Sub-Tabellen
  0x033F, 0x03F3, 0x032F, 0x03F2, 0x03F1, 0x0849, 0x0B49, 0x0B51,
  // Sub-Tabelle gre 6 mit vorherigen Code 0100 und 7 Sub-Tabellen
  0x0858, 0x0859, 0x0959, 0x06E6, 0x085A, 0x06C9, 0x065E, 0x06BA,
  0x06E5, 0x0859, 0x06D7, 0x06E4, 0x068C, 0x06C8, 0x0857, 0x063E,
  0x066D, 0x06D6, 0x06E3, 0x069B, 0x06B9, 0x06AA, 0x06E2, 0x061E,
  0x06E1, 0x065D, 0x06D5, 0x067C, 0x06C7, 0x064D, 0x068B, 0x06B8,
  0x06D4, 0x069A, 0x06A9, 0x066C, 0x06C6, 0x063D, 0x06D3, 0x062D,
  0x06D2, 0x061D, 0x067B, 0x06B7, 0x06D1, 0x065C, 0x06C5, 0x068A,
  0x06A8, 0x0699, 0x064C, 0x06C4, 0x066B, 0x06B6, 0x0844, 0x063C,
  0x06C3, 0x067A, 0x06A7, 0x062C, 0x06C2, 0x065B, 0x06B5, 0x061C,
  // Sub-Tabelle gre 2 mit vorherigen Code 0101 und 4 Sub-Tabellen
  0x0B40, 0x0A48, 0x0A4B, 0x0A4F,
  // Sub-Tabelle gre 5 mit vorherigen Code 0110 und 2 Sub-Tabellen
  0x0558, 0x0585, 0x0529, 0x0567, 0x0576, 0x0592, 0x0519, 0x0591,
  0x0548, 0x0584, 0x0557, 0x0575, 0x0538, 0x0583, 0x0566, 0x0528,
  0x0582, 0x0518, 0x0547, 0x0574, 0x0581, 0x0848, 0x0556, 0x0565,
  0x0517, 0x0847, 0x0473, 0x0473, 0x0537, 0x0527, 0x0472, 0x0472,
  // Sub-Tabelle gre 4 mit vorherigen Code 0111 und 1 Sub-Tabellen
  0x0446, 0x0464, 0x0455, 0x0471, 0x0436, 0x0463, 0x0445, 0x0454,
  0x0426, 0x0462, 0x0416, 0x0461, 0x083E, 0x0435, 0x0453, 0x0444,
  // Sub-Tabelle gre 3 mit vorherigen Code 1000 und 3 Sub-Tabellen
  0x083D, 0x093E, 0x0351, 0x083F, 0x0324, 0x0342, 0x0333, 0x0314,
  // Sub-Tabelle gre 3 mit vorherigen Code 1001 und 1 Sub-Tabellen
  0x0341, 0x083D, 0x0323, 0x0332, 0x0213, 0x0213, 0x0231, 0x0231,
  // Sub-Tabelle gre 2 mit vorherigen Code 1010 und 1 Sub-Tabellen
  0x083A, 0x0222, 0x0112, 0x0112,
  // Sub-Tabelle gre 2 mit vorherigen Code 1011 und 0 Sub-Tabellen
  0x0121, 0x0121, 0x0202, 0x0220,
  // LEVEL3 Tabellen - Lnge 110
  // Sub-Tabelle gre 1 mit vorherigen Code 0001000 und 0 Sub-Tabellen
  0x018F, 0x017F,
  // Sub-Tabelle gre 1 mit vorherigen Code 0010101 und 0 Sub-Tabellen
  0x011F, 0x01F0,
  // Sub-Tabelle gre 4 mit vorherigen Code 0010110 und 0 Sub-Tabellen
  0x020F, 0x020F, 0x020F, 0x020F, 0x04EE, 0x04DE, 0x04ED, 0x04CE,
  0x04EC, 0x04DD, 0x04BE, 0x04EB, 0x04CD, 0x04DC, 0x04AE, 0x04EA,
  // Sub-Tabelle gre 4 mit vorherigen Code 0010111 und 0 Sub-Tabellen
  0x04BD, 0x04DB, 0x04CC, 0x049E, 0x04E9, 0x04AD, 0x04DA, 0x04BC,
  0x04CB, 0x048E, 0x04E8, 0x049D, 0x04D9, 0x047E, 0x04E7, 0x04AC,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100000000 und 0 Sub-Tabellen
  0x01CA, 0x01BB,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100000001 und 0 Sub-Tabellen
  0x018D, 0x01D8,
  // Sub-Tabelle gre 2 mit vorherigen Code 0100000010 und 0 Sub-Tabellen
  0x020E, 0x02E0, 0x010D, 0x010D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100000100 und 0 Sub-Tabellen
  0x016E, 0x019C,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100001001 und 0 Sub-Tabellen
  0x01AB, 0x017D,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100001110 und 0 Sub-Tabellen
  0x014E, 0x012E,
  // Sub-Tabelle gre 1 mit vorherigen Code 0100110110 und 0 Sub-Tabellen
  0x01D0, 0x010C,
  // Sub-Tabelle gre 4 mit vorherigen Code 010100 und 3 Sub-Tabellen
  0x0489, 0x0498, 0x04C1, 0x044B, 0x081B, 0x043B, 0x081B, 0x041A,
  0x03B4, 0x03B4, 0x046A, 0x04A6, 0x0479, 0x0497, 0x0818, 0x0490,
  // Sub-Tabelle gre 3 mit vorherigen Code 010101 und 3 Sub-Tabellen
  0x03B3, 0x0388, 0x0817, 0x03B2, 0x0817, 0x0818, 0x0396, 0x03A4,
  // Sub-Tabelle gre 3 mit vorherigen Code 010110 und 1 Sub-Tabellen
  0x0817, 0x0387, 0x033A, 0x03A3, 0x0359, 0x0395, 0x032A, 0x03A2,
  // Sub-Tabelle gre 3 mit vorherigen Code 010111 und 0 Sub-Tabellen
  0x03A1, 0x0368, 0x0386, 0x0377, 0x0349, 0x0394, 0x0339, 0x0393,
  // Sub-Tabelle gre 1 mit vorherigen Code 011010101 und 0 Sub-Tabellen
  0x0108, 0x0180,
  // Sub-Tabelle gre 1 mit vorherigen Code 011011001 und 0 Sub-Tabellen
  0x0107, 0x0170,
  // Sub-Tabelle gre 1 mit vorherigen Code 01111100 und 0 Sub-Tabellen
  0x0106, 0x0160,
  // Sub-Tabelle gre 1 mit vorherigen Code 1000000 und 0 Sub-Tabellen
  0x0125, 0x0152,
  // Sub-Tabelle gre 2 mit vorherigen Code 1000001 und 0 Sub-Tabellen
  0x0115, 0x0115, 0x0205, 0x0250,
  // Sub-Tabelle gre 1 mit vorherigen Code 1000011 und 0 Sub-Tabellen
  0x0134, 0x0143,
  // Sub-Tabelle gre 1 mit vorherigen Code 1001001 und 0 Sub-Tabellen
  0x0104, 0x0140,
  // Sub-Tabelle gre 1 mit vorherigen Code 101000 und 0 Sub-Tabellen
  0x0103, 0x0130,
  // LEVEL4 Tabellen - Lnge 14
  // Sub-Tabelle gre 1 mit vorherigen Code 0101000100 und 0 Sub-Tabellen
  0x01C0, 0x010B,
  // Sub-Tabelle gre 1 mit vorherigen Code 0101000110 und 0 Sub-Tabellen
  0x01B0, 0x010A,
  // Sub-Tabelle gre 1 mit vorherigen Code 0101001110 und 0 Sub-Tabellen
  0x01A0, 0x0109,
  // Sub-Tabelle gre 1 mit vorherigen Code 010101010 und 0 Sub-Tabellen
  0x012B, 0x015A,
  // Sub-Tabelle gre 1 mit vorherigen Code 010101100 und 0 Sub-Tabellen
  0x01A5, 0x011B,
  // Sub-Tabelle gre 1 mit vorherigen Code 010101101 und 0 Sub-Tabellen
  0x01B1, 0x0169,
  // Sub-Tabelle gre 1 mit vorherigen Code 010110000 und 0 Sub-Tabellen
  0x014A, 0x0178,


};


const HuffTabLookup HuffInfo[] = {
  { 0, 2, 0 }, // Huffman-Tabelle 1 (echt kodiert)
  { 0, 1, 6 }, // Huffman-Tabelle 2 (echt kodiert)
  { 0, 2, 18 }, // Huffman-Tabelle 3 (echt kodiert)
  { 0, 0, 0 }, // Huffman-Tabelle 4 (nicht kodiert)
  { 0, 1, 30 }, // Huffman-Tabelle 5 (echt kodiert)
  { 0, 3, 52 }, // Huffman-Tabelle 6 (echt kodiert)
  { 0, 2, 76 }, // Huffman-Tabelle 7 (echt kodiert)
  { 0, 3, 130 }, // Huffman-Tabelle 8 (echt kodiert)
  { 0, 3, 182 }, // Huffman-Tabelle 9 (echt kodiert)
  { 0, 2, 232 }, // Huffman-Tabelle 10 (echt kodiert)
  { 0, 3, 324 }, // Huffman-Tabelle 11 (echt kodiert)
  { 0, 3, 412 }, // Huffman-Tabelle 12 (echt kodiert)
  { 0, 4, 498 }, // Huffman-Tabelle 13 (echt kodiert)
  { 0, 0, 0 }, // Huffman-Tabelle 14 (nicht kodiert)
  { 0, 4, 870 }, // Huffman-Tabelle 15 (echt kodiert)
  { 1, 4, 1186 }, // Huffman-Tabelle 16 (echt kodiert)
  { 2, 4, 1186 }, // Huffman-Tabelle 17 (nutzt 16)
  { 3, 4, 1186 }, // Huffman-Tabelle 18 (nutzt 16)
  { 4, 4, 1186 }, // Huffman-Tabelle 19 (nutzt 16)
  { 6, 4, 1186 }, // Huffman-Tabelle 20 (nutzt 16)
  { 8, 4, 1186 }, // Huffman-Tabelle 21 (nutzt 16)
  { 10, 4, 1186 }, // Huffman-Tabelle 22 (nutzt 16)
  { 13, 4, 1186 }, // Huffman-Tabelle 23 (nutzt 16)
  { 4, 4, 1562 }, // Huffman-Tabelle 24 (echt kodiert)
  { 5, 4, 1562 }, // Huffman-Tabelle 25 (nutzt 24)
  { 6, 4, 1562 }, // Huffman-Tabelle 26 (nutzt 24)
  { 7, 4, 1562 }, // Huffman-Tabelle 27 (nutzt 24)
  { 8, 4, 1562 }, // Huffman-Tabelle 28 (nutzt 24)
  { 9, 4, 1562 }, // Huffman-Tabelle 29 (nutzt 24)
  { 11, 4, 1562 }, // Huffman-Tabelle 30 (nutzt 24)
  { 13, 4, 1562 }, // Huffman-Tabelle 31 (nutzt 24)
};


/* tables for quadruples
 * format 0xAB
 *  A = length of codeword
 *  B = codeword
 */
const unsigned char quadTable[64+16] = {
	/* table A */
	0x6b, 0x6f, 0x6d, 0x6e, 0x67, 0x65, 0x59, 0x59, 
	0x56, 0x56, 0x53, 0x53, 0x5a, 0x5a, 0x5c, 0x5c, 
	0x42, 0x42, 0x42, 0x42, 0x41, 0x41, 0x41, 0x41, 
	0x44, 0x44, 0x44, 0x44, 0x48, 0x48, 0x48, 0x48, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 0x10, 
	/* table B */
	0x4f, 0x4e, 0x4d, 0x4c, 0x4b, 0x4a, 0x49, 0x48, 
	0x47, 0x46, 0x45, 0x44, 0x43, 0x42, 0x41, 0x40, 
};

const int quadTabOffset[2] = {0, 64};
const int quadTabMaxBits[2] = {6, 4};